commit 07651f8fa62390cfe568d636cd2aa53c6ce13b81
Author: Leszek Koltunski <leszek@distorted.org>
Date:   Wed Jul 13 02:01:33 2016 +0100

    beginnings of support for drawing the Region in Vertex3D app.

diff --git a/src/main/java/org/distorted/library/EffectTypes.java b/src/main/java/org/distorted/library/EffectTypes.java
index 67563f4..f9d4285 100644
--- a/src/main/java/org/distorted/library/EffectTypes.java
+++ b/src/main/java/org/distorted/library/EffectTypes.java
@@ -58,7 +58,7 @@ public enum EffectTypes
 
   static void reset(int[] maxtable)
     {
-    maxtable[0] = 5;  // By default, there can be a maximum 5 MATRIX effects acting on a single
+    maxtable[0] =10;  // By default, there can be a maximum 10 MATRIX effects acting on a single
                       // DistortedObject at any given time. This can be changed with a call to
                       // EffectQueueMatrix.setMax(int)
 
